[evolution-data-server] Check for gtk version below 2.21.1 for comptability with gseal changes



commit 905a30860e08f0264c746ca7a92d5b405015196c
Author: Chenthill Palanisamy <pchenthill novell com>
Date:   Thu Jun 10 12:14:09 2010 +0530

    Check for gtk version below 2.21.1 for comptability with gseal changes

 libedataserverui/gtk-compat.h |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)
---
diff --git a/libedataserverui/gtk-compat.h b/libedataserverui/gtk-compat.h
index a070722..109ced3 100644
--- a/libedataserverui/gtk-compat.h
+++ b/libedataserverui/gtk-compat.h
@@ -4,16 +4,17 @@
 #include <gtk/gtk.h>
 
 /* Provide a compatibility layer for accessor functions introduced
  * in GTK+ 2.22 which we need to build with sealed GDK.
  * That way it is still possible to build with GTK+ 2.20.
  */
 
-#if !GTK_CHECK_VERSION(2,21,2)
+#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 21) \
+	|| (GTK_MINOR_VERSION == 21 && GTK_MICRO_VERSION < 1)
 
 #define gdk_drag_context_get_actions(context)          (context)->actions
 #define gdk_drag_context_get_suggested_action(context) (context)->suggested_action
 #define gdk_drag_context_get_selected_action(context)  (context)->action
 
-#endif /* GTK_CHECK_VERSION(2, 21, 0) */
+#endif 
 
 #endif /* __GTK_COMPAT_H__ */
@@ -4,16 +4,17 @@
 
 /* Provide a compatibility layer for accessor functions introduced
- * in GTK+ 2.22 which we need to build with sealed GDK.
+ * in GTK+ 2.21.1 which we need to build with sealed GDK.
  * That way it is still possible to build with GTK+ 2.20.
  */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]